@@ -6,6 +6,7 @@
 """
 import inspect
 from types import MethodType
+from datetime import datetime
 
 
 class DatabaseExtension(object):
@@ -17,14 +18,14 @@ class DatabaseExtension(object):
             """Create all tables"""
             Database.Base.metadata.create_all(bind = self.engine)
         Database.create_tables = create_tables
-       
+
         def drop_tables(self):
             """Drop all tables"""
             Database.Base.metadata.drop_all(bind = self.engine)
         Database.drop_tables = drop_tables
 
         def load_data(self, data):
-            """Load data into database from a module or an iterable of items 
+            """Load data into database from a module or an iterable of items
             All items must be derived from Database.Base, otherwise will be ignored.
             If the data paramter is a module, will try to load data from variables ending with 's' in that module.
             """
@@ -44,18 +45,18 @@ class DatabaseExtension(object):
 
 
 class SessionExtension(object):
-    """Extends the database session"""
+    """Extend the database session"""
     @staticmethod
     def extend(session):
         """Extend session"""
         def add_then_commit(session, obj):
             session.add(obj)
-            session.commit()        
+            session.commit()
         session.add_then_commit = MethodType(add_then_commit, session)
 
         def add_all_then_commit(session, items):
             session.add_all(items)
-            session.commit()        
+            session.commit()
         session.add_all_then_commit = MethodType(add_all_then_commit, session)
 
         def delete_then_commit(session, obj):
@@ -63,4 +64,16 @@ class SessionExtension(object):
             session.commit()
         session.delete_then_commit = MethodType(delete_then_commit, session)
 
-        return session  
+        return session
+
+
+class ModelExtension(object):
+    """Extend each model"""
+
+    @staticmethod
+    def before_insert_listener(mapper, connection, target):
+        target.created_at = datetime.now()
+
+    @staticmethod
+    def before_update_listener(mapper, connection, target):
+        target.updated_at = datetime.now()
\ No newline at end of file
